@@ -108,6 +108,9 @@ class MainWindow(QWidget):
         self.setup_widget = SetupWidget(config.api, config.player)
         self.layout.addWidget(self.setup_widget)
         self.setup_widget.done.connect(self.on_setup_done)
+        # Setting focus on the continue button after the first time.
+        if None not in (config.api, config.player):
+            self.setup_widget.continue_btn.setFocus()
 
     def closeEvent(self, event) -> None:
         """
@@ -432,17 +435,17 @@ class MainWindow(QWidget):
 
         logging.info("Total delay is %d ms", lag)
         if lag > 0:
-            self.player.position += lag
+            self.player.seek(lag, relative=True)
         elif lag < 0:
             # If a negative delay is larger than the current player position,
             # the player position is set to zero after the lag has passed
             # with a timer.
             if self.player.position < -lag:
                 self.sync_timer = QTimer(self)
-                self.sync_timer.singleShot(
-                    -lag, lambda: self.change_video_position(0))
+                self.sync_timer.singleShot(-self.player.position - lag,
+                                           lambda: self.player.seek(0))
             else:
-                self.player.position += lag
+                self.player.seek(lag, relative=True)
 
     def init_spotify_web_api(self) -> None:
         """
